# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin

from acomea.settings.models import AcomeaSettings, AcomeaSqlServerSettings, MailupFieldMap


class AcomeaSqlServerSettingsAdminForm(forms.ModelForm):
    class Meta:
        model = AcomeaSqlServerSettings
        widgets = {
            'password': forms.PasswordInput(),
        }


class AcomeaSettingsAdmin(ExtendibleModelAdmin):
    list_display = (
        'site', 'name', 'is_soap_enabled', 'soap_off_redirect_url',
        'is_analytics_enabled', 'get_edit_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                'site', 'name', 'is_soap_enabled',
                'soap_off_redirect_url',
            )
        }),
        (_('logs admin'), {
            'fields': (
                'is_analytics_enabled', 'sql_server',
            ),
        }),
    )


class AcomeaSqlServerSettingsAdmin(ExtendibleModelAdmin):
    form = AcomeaSqlServerSettingsAdminForm
    list_display = (
        'ip', 'port', 'database', 'username',
        'get_edit_icon', 'get_delete_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                'ip', 'port', 'database', 'username', 'password'
            )
        }),
    )


class MailupFieldMapAdmin(ExtendibleModelAdmin):

    list_display = ('last_modifier', 'date_last_modify', 'get_edit_icon',)

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (_('Static Fields'), {
            'fields': (
                ('email_field_export_file', 'email_field_mailup',),
                ('first_name_field_export_file', 'first_name_field_mailup',),
                ('last_name_field_export_file', 'last_name_field_mailup',),
                ('group_field_export_file',),
            )
        }),
        (_('Dynamic Fields'), {
            'fields': (
                ('field_1_export_file', 'field_1_mailup',),
                ('field_2_export_file', 'field_2_mailup',),
                ('field_3_export_file', 'field_3_mailup',),
                ('field_4_export_file', 'field_4_mailup',),
                ('field_5_export_file', 'field_5_mailup',),
                ('field_6_export_file', 'field_6_mailup',),
                ('field_7_export_file', 'field_7_mailup',),
                ('field_8_export_file', 'field_8_mailup',),
                ('field_9_export_file', 'field_9_mailup',),
                ('field_10_export_file', 'field_10_mailup',),
                ('field_11_export_file', 'field_11_mailup',),
                ('field_12_export_file', 'field_12_mailup',),
                ('field_13_export_file', 'field_13_mailup',),
                ('field_14_export_file', 'field_14_mailup',),
                ('field_15_export_file', 'field_15_mailup',),
                ('field_16_export_file', 'field_16_mailup',),
                ('field_17_export_file', 'field_17_mailup',),
                ('field_18_export_file', 'field_18_mailup',),
                ('field_19_export_file', 'field_19_mailup',),
                ('field_20_export_file', 'field_20_mailup',),
                ('field_21_export_file', 'field_21_mailup',),
                ('field_22_export_file', 'field_22_mailup',),
                ('field_23_export_file', 'field_23_mailup',),
                ('field_24_export_file', 'field_24_mailup',),
                ('field_25_export_file', 'field_25_mailup',),
                ('field_26_export_file', 'field_26_mailup',),
                ('field_27_export_file', 'field_27_mailup',),
                ('field_28_export_file', 'field_28_mailup',),
                ('field_29_export_file', 'field_29_mailup',),
                ('field_30_export_file', 'field_30_mailup',),
            )
        }),
    )

    readonly_fields = (
        'email_field_export_file',
        'email_field_mailup',
        'first_name_field_export_file',
        'first_name_field_mailup',
        'last_name_field_export_file',
        'last_name_field_mailup',
        'group_field_export_file',
    )

admin.site.register(AcomeaSettings, AcomeaSettingsAdmin)
admin.site.register(AcomeaSqlServerSettings, AcomeaSqlServerSettingsAdmin)
admin.site.register(MailupFieldMap, MailupFieldMapAdmin)
