# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from acomea.settings.models import AcomeaSettings
from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs = {
            'title': "Settings",
            'display': "tabs",
            'children': [
                Models(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)


class SettingsDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs = {
            'title': "Settings",
            'display': "tabs",
            'children': [
                Models(),
            ]
        }
        super(SettingsDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Main Models"),
            'models': ('acomea.settings.models.*',),
        }
        super(Models, self).__init__(**kwargs)


class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Others"),
            'models': (),
        }
        super(OtherModels, self).__init__(**kwargs)




class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(SettingsDashboard, 'acomea.settings')
# Used in /admin/Settings
admin_tools.dashboard.register(DefaultAppDashboard, 'acomea.settings')
