# coding: utf-8

from django.conf import settings
from django.contrib.sites.models import Site
from django.core.cache import cache
from django.db import models
from django.utils.translation import ugettext_lazy as _


from jmb.core.db.models import DateModel, UserModel


class AcomeaSettings(DateModel, UserModel):
    site = models.OneToOneField(
        Site,
        related_name="settings"
    )
    name = models.CharField(
        verbose_name=_("Name"),
        max_length=100,
        default="AcomeA global settings",
    )
    is_soap_enabled = models.BooleanField(
        verbose_name=_("Soap enabled"),
        default=True,
    )
    soap_off_redirect_url = models.URLField(
        blank=True, null=True,
        verbose_name=_('redirect url when soap is off')
    )
    is_analytics_enabled = models.BooleanField(
        verbose_name=_('analytics is enabled'),
        default=True
    )
    sql_server = models.ForeignKey(
        'settings.AcomeaSqlServerSettings',
        verbose_name=_('Analytics connection'),
        blank=True, null=True
    )

    def save(self, *args, **kwargs):
        cache.delete('jmb_analytics_connection_string')
        cache.delete('jmb_analytics_enabled')
        super(AcomeaSettings, self).save(*args, **kwargs)

    class Meta(object):
        verbose_name = _('Acomea settings')
        verbose_name_plural = _('Acomea settings')

    def __unicode__(self):
        return u"{}".format(self.name)


class AcomeaSqlServerSettings(DateModel, UserModel):
    ip = models.IPAddressField(
        verbose_name=_('Ip')
    )
    port = models.IntegerField(
        verbose_name=_('Port'),
        default=1433
    )
    database = models.CharField(
        verbose_name=_("Database"),
        max_length=100,
    )
    username = models.CharField(
        verbose_name=_("Username"),
        max_length=100,
    )
    password = models.CharField(
        verbose_name=_("password"),
        max_length=100,
    )

    @property
    def connection_string(self):
        return "DRIVER=FreeTDS;SERVER={};PORT={};DATABASE={};UID={};PWD={};TDS_Version=8.0;".format(
            self.ip, self.port, self.database, self.username, self.password
        )

    class Meta(object):
        verbose_name = _('Acomea sql server settings')
        verbose_name_plural = _('Acomea sql server settings')

    def __unicode__(self):
        return self.connection_string


class MailupFieldMap(DateModel, UserModel):
    """
    Model to set mapping of mailup sync
    """
    # TODO: in docstring indicare il comando che utilizzerà il modello

    # STATIC FIELD
    email_field_export_file = models.CharField(
        max_length=30,
        default='Email',
        verbose_name=_(u"email field in export file")
    )
    email_field_mailup = models.CharField(
        max_length=30,
        default='Email',
        verbose_name=_(u"email field in mailup")
    )
    first_name_field_export_file = models.CharField(
        max_length=30,
        default='Nome',
        verbose_name=_(u"first name field in export file")
    )
    first_name_field_mailup = models.CharField(
        max_length=30,
        default='Nome',
        verbose_name=_(u"first name field in mailup")
    )
    last_name_field_export_file = models.CharField(
        max_length=30,
        default='Cognome',
        verbose_name=_(u"last name field in export file")
    )
    last_name_field_mailup = models.CharField(
        max_length=30,
        default='Cognome',
        verbose_name=_(u"last name field in mailup")
    )
    group_field_export_file = models.CharField(
        max_length=30,
        default='Gruppi',
        verbose_name=_(u"group field in export file")
    )

    # DYNAMIC FIELD
    field_1_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 1 in export file")
    )
    field_1_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 1 in mailup")
    )
    field_2_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 2 in export file")
    )
    field_2_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 2 in mailup")
    )
    field_3_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 3 in export file")
    )
    field_3_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 3 in mailup")
    )
    field_4_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 4 in export file")
    )
    field_4_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 4 in mailup")
    )
    field_5_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 5 in export file")
    )
    field_5_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 5 in mailup")
    )
    field_6_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 6 in export file")
    )
    field_6_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 6 in mailup")
    )
    field_7_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 7 in export file")
    )
    field_7_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 7 in mailup")
    )
    field_8_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 8 in export file")
    )
    field_8_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 8 in mailup")
    )
    field_9_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 9 in export file")
    )
    field_9_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 9 in mailup")
    )
    field_10_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 10 in export file")
    )
    field_10_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 10 in mailup")
    )
    field_11_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 11 in export file")
    )
    field_11_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 11 in mailup")
    )
    field_12_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 12 in export file")
    )
    field_12_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 12 in mailup")
    )
    field_13_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 13 in export file")
    )
    field_13_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 13 in mailup")
    )
    field_14_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 14 in export file")
    )
    field_14_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 14 in mailup")
    )
    field_15_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 15 in export file")
    )
    field_15_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 15 in mailup")
    )
    field_16_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 16 in export file")
    )
    field_16_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 16 in mailup")
    )
    field_17_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 17 in export file")
    )
    field_17_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 17 in mailup")
    )
    field_18_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 18 in export file")
    )
    field_18_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 18 in mailup")
    )
    field_19_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 19 in export file")
    )
    field_19_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 19 in mailup")
    )
    field_20_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 20 in export file")
    )
    field_20_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 20 in mailup")
    )
    field_21_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 21 in export file")
    )
    field_21_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 21 in mailup")
    )
    field_22_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 22 in export file")
    )
    field_22_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 22 in mailup")
    )
    field_23_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 23 in export file")
    )
    field_23_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 23 in mailup")
    )
    field_24_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 24 in export file")
    )
    field_24_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 24 in mailup")
    )
    field_25_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 25 in export file")
    )
    field_25_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 25 in mailup")
    )
    field_26_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 26 in export file")
    )
    field_26_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 26 in mailup")
    )
    field_27_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 27 in export file")
    )
    field_27_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 27 in mailup")
    )
    field_28_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 28 in export file")
    )
    field_28_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 28 in mailup")
    )
    field_29_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 29 in export file")
    )
    field_29_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 29 in mailup")
    )
    field_30_export_file = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 30 in export file")
    )
    field_30_mailup = models.CharField(
        blank=True, null=True,
        max_length=30,
        verbose_name=_(u"Field 30 in mailup")
    )


if settings.CMS_ENABLED:
    import acomea.settings.cms.plugins
    import acomea.settings.cms.app

