# -*- coding: utf-8 -*-

from django.contrib.sites.models import Site
from django.http import HttpResponseRedirect
from django.core.exceptions import MultipleObjectsReturned

from jmb.core.middleware.force_response import ForceResponse
from acomea.settings.models import AcomeaSettings


def redirect_when_soap_is_off():
    try:
        site = Site.objects.get_current()
        if hasattr(site, 'settings'):
            site_settings = site.settings
            if not site_settings.is_soap_enabled and site_settings.soap_off_redirect_url:
                raise ForceResponse(HttpResponseRedirect(site_settings.soap_off_redirect_url))
    except (Site.DoesNotExist, AcomeaSettings.DoesNotExist, MultipleObjectsReturned):
        pass


def get_custom_connection_string():
    try:
        site = Site.objects.get_current()
        if hasattr(site, 'settings'):
            site_settings = site.settings
            if site_settings.sql_server:
                return site_settings.sql_server.connection_string
            return ''
    except (Site.DoesNotExist, AcomeaSettings.DoesNotExist, MultipleObjectsReturned):
        return ''
